psychopy_ext.exp.OrderedDict — psychopy_ext 0.5.4 documentation
Author: Jonas Kubilius
Description: A framework for a rapid reproducible design, analysis and plotting of experiments in neuroscience and psychology

# psychopy_ext.exp.OrderedDict

class `psychopy_ext.exp.` `OrderedDict`(*args, **kwds)

  OrderedDict code (because some are stuck with Python 2.5)

  Produces an dictionary but with (key, value) pairs in the defined order.

  Created by Raymond Hettinger on Wed, 18 Mar 2009, under the MIT License <http://code.activestate.com/recipes/576693/>_

  `__init__`(*args, **kwds)

  Methods

  `__init__`(*args, **kwds) |
  `clear`() |
  `copy`() |
  `fromkeys`(iterable[, value]) |
  `get`((k[,d]) -> D[k] if k in D, ...) |
  `has_key`((k) -> True if D has a key k, else False) |
  `items`() |
  `iteritems`() |
  `iterkeys`() |
  `itervalues`() |
  `keys`() |
  `pop`(key, *args) |
  `popitem`([last]) |
  `setdefault`(key[, default]) |
  `update`([other]) |
  `values`() |
  `viewitems`(...) |
  `viewkeys`(...) |
  `viewvalues`(...) |